# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: blickfeld/config/advanced.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from blickfeld import options_pb2 as blickfeld_dot_options__pb2
from blickfeld.stream import connection_pb2 as blickfeld_dot_stream_dot_connection__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='blickfeld/config/advanced.proto',
  package='blickfeld.protocol.config',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1f\x62lickfeld/config/advanced.proto\x12\x19\x62lickfeld.protocol.config\x1a\x17\x62lickfeld/options.proto\x1a!blickfeld/stream/connection.proto\"\xbf\x08\n\x08\x41\x64vanced\x12>\n\x08\x64\x65tector\x18\x01 \x01(\x0b\x32,.blickfeld.protocol.config.Advanced.Detector\x12\x42\n\nprocessing\x18\x02 \x01(\x0b\x32..blickfeld.protocol.config.Advanced.Processing\x12:\n\x06server\x18\x03 \x01(\x0b\x32*.blickfeld.protocol.config.Advanced.Server\x12U\n\x14time_synchronization\x18\x04 \x01(\x0b\x32\x37.blickfeld.protocol.config.Advanced.TimeSynchronization\x1a:\n\x08\x44\x65tector\x12.\n\x0bsensitivity\x18\x01 \x01(\x02:\x01\x31\x42\x16\x81\xb5\x18\x9a\x99\x99\x99\x99\x99\xe9?\x89\xb5\x18\x33\x33\x33\x33\x33\x33\xf3?\x1a\xa9\x01\n\nProcessing\x12/\n\x0crange_offset\x18\x01 \x01(\x02:\x01\x30\x42\x16\x81\xb5\x18\x00\x00\x00\x00\x00\x00\x00\xc0\x89\xb5\x18\x00\x00\x00\x00\x00\x00\x00@\x12.\n\x1aimu_static_rotation_offset\x18\x02 \x03(\x02\x42\n\x10\x01\xa0\xb5\x18\x12\xb0\xb5\x18\x01\x12:\n\x17horizontal_phase_offset\x18\x03 \x01(\x02:\x01\x30\x42\x16\x81\xb5\x18\x8d\xed\xb5\xa0\xf7\xc6\x00\xbf\x89\xb5\x18\x8d\xed\xb5\xa0\xf7\xc6\x00?\x1a\x63\n\x06Server\x12Y\n default_point_cloud_subscription\x18\x01 \x01(\x0b\x32/.blickfeld.protocol.stream.Subscribe.PointCloud\x1a\xce\x03\n\x13TimeSynchronization\x12J\n\x03ntp\x18\x01 \x01(\x0b\x32;.blickfeld.protocol.config.Advanced.TimeSynchronization.NTPH\x00\x12J\n\x03ptp\x18\x02 \x01(\x0b\x32;.blickfeld.protocol.config.Advanced.TimeSynchronization.PTPH\x00\x1a\x30\n\x03NTP\x12)\n\x07servers\x18\x01 \x03(\tB\x18\xb0\xb5\x18\x01\xaa\xb5\x18\x10[[:alnum:]\\.\\-]+\x1a\xde\x01\n\x03PTP\x12\x11\n\x06\x64omain\x18\x01 \x01(\r:\x01\x30\x12h\n\x0f\x64\x65lay_mechanism\x18\x02 \x01(\x0e\x32J.blickfeld.protocol.config.Advanced.TimeSynchronization.PTP.DelayMechanism:\x03\x45\x32\x45\x12\x36\n\x14unicast_destinations\x18\x03 \x03(\tB\x18\xb0\xb5\x18\x01\xaa\xb5\x18\x10[[:alnum:]\\.\\-]+\"\"\n\x0e\x44\x65layMechanism\x12\x07\n\x03\x45\x32\x45\x10\x01\x12\x07\n\x03P2P\x10\x02\x42\x0c\n\x04kind\x12\x04\xb0\xb5\x18\x01'
  ,
  dependencies=[blickfeld_dot_options__pb2.DESCRIPTOR,blickfeld_dot_stream_dot_connection__pb2.DESCRIPTOR,])



_ADVANCED_TIMESYNCHRONIZATION_PTP_DELAYMECHANISM = _descriptor.EnumDescriptor(
  name='DelayMechanism',
  full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.PTP.DelayMechanism',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='E2E', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='P2P', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1162,
  serialized_end=1196,
)
_sym_db.RegisterEnumDescriptor(_ADVANCED_TIMESYNCHRONIZATION_PTP_DELAYMECHANISM)


_ADVANCED_DETECTOR = _descriptor.Descriptor(
  name='Detector',
  full_name='blickfeld.protocol.config.Advanced.Detector',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='sensitivity', full_name='blickfeld.protocol.config.Advanced.Detector.sensitivity', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\232\231\231\231\231\231\351?\211\265\030333333\363?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=414,
  serialized_end=472,
)

_ADVANCED_PROCESSING = _descriptor.Descriptor(
  name='Processing',
  full_name='blickfeld.protocol.config.Advanced.Processing',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='range_offset', full_name='blickfeld.protocol.config.Advanced.Processing.range_offset', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\000\000\000\000\000\000\000\300\211\265\030\000\000\000\000\000\000\000@', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='imu_static_rotation_offset', full_name='blickfeld.protocol.config.Advanced.Processing.imu_static_rotation_offset', index=1,
      number=2, type=2, cpp_type=6, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\020\001\240\265\030\022\260\265\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='horizontal_phase_offset', full_name='blickfeld.protocol.config.Advanced.Processing.horizontal_phase_offset', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\201\265\030\215\355\265\240\367\306\000\277\211\265\030\215\355\265\240\367\306\000?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=475,
  serialized_end=644,
)

_ADVANCED_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='blickfeld.protocol.config.Advanced.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_point_cloud_subscription', full_name='blickfeld.protocol.config.Advanced.Server.default_point_cloud_subscription', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=646,
  serialized_end=745,
)

_ADVANCED_TIMESYNCHRONIZATION_NTP = _descriptor.Descriptor(
  name='NTP',
  full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.NTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='servers', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.NTP.servers', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001\252\265\030\020[[:alnum:]\\.\\-]+', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=923,
  serialized_end=971,
)

_ADVANCED_TIMESYNCHRONIZATION_PTP = _descriptor.Descriptor(
  name='PTP',
  full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.PTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='domain', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.PTP.domain', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay_mechanism', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.PTP.delay_mechanism', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unicast_destinations', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.PTP.unicast_destinations', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\260\265\030\001\252\265\030\020[[:alnum:]\\.\\-]+', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ADVANCED_TIMESYNCHRONIZATION_PTP_DELAYMECHANISM,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=974,
  serialized_end=1196,
)

_ADVANCED_TIMESYNCHRONIZATION = _descriptor.Descriptor(
  name='TimeSynchronization',
  full_name='blickfeld.protocol.config.Advanced.TimeSynchronization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ntp', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.ntp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ptp', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.ptp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADVANCED_TIMESYNCHRONIZATION_NTP, _ADVANCED_TIMESYNCHRONIZATION_PTP, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='blickfeld.protocol.config.Advanced.TimeSynchronization.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\260\265\030\001'),
  ],
  serialized_start=748,
  serialized_end=1210,
)

_ADVANCED = _descriptor.Descriptor(
  name='Advanced',
  full_name='blickfeld.protocol.config.Advanced',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='detector', full_name='blickfeld.protocol.config.Advanced.detector', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='processing', full_name='blickfeld.protocol.config.Advanced.processing', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='server', full_name='blickfeld.protocol.config.Advanced.server', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_synchronization', full_name='blickfeld.protocol.config.Advanced.time_synchronization', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ADVANCED_DETECTOR, _ADVANCED_PROCESSING, _ADVANCED_SERVER, _ADVANCED_TIMESYNCHRONIZATION, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=1210,
)

_ADVANCED_DETECTOR.containing_type = _ADVANCED
_ADVANCED_PROCESSING.containing_type = _ADVANCED
_ADVANCED_SERVER.fields_by_name['default_point_cloud_subscription'].message_type = blickfeld_dot_stream_dot_connection__pb2._SUBSCRIBE_POINTCLOUD
_ADVANCED_SERVER.containing_type = _ADVANCED
_ADVANCED_TIMESYNCHRONIZATION_NTP.containing_type = _ADVANCED_TIMESYNCHRONIZATION
_ADVANCED_TIMESYNCHRONIZATION_PTP.fields_by_name['delay_mechanism'].enum_type = _ADVANCED_TIMESYNCHRONIZATION_PTP_DELAYMECHANISM
_ADVANCED_TIMESYNCHRONIZATION_PTP.containing_type = _ADVANCED_TIMESYNCHRONIZATION
_ADVANCED_TIMESYNCHRONIZATION_PTP_DELAYMECHANISM.containing_type = _ADVANCED_TIMESYNCHRONIZATION_PTP
_ADVANCED_TIMESYNCHRONIZATION.fields_by_name['ntp'].message_type = _ADVANCED_TIMESYNCHRONIZATION_NTP
_ADVANCED_TIMESYNCHRONIZATION.fields_by_name['ptp'].message_type = _ADVANCED_TIMESYNCHRONIZATION_PTP
_ADVANCED_TIMESYNCHRONIZATION.containing_type = _ADVANCED
_ADVANCED_TIMESYNCHRONIZATION.oneofs_by_name['kind'].fields.append(
  _ADVANCED_TIMESYNCHRONIZATION.fields_by_name['ntp'])
_ADVANCED_TIMESYNCHRONIZATION.fields_by_name['ntp'].containing_oneof = _ADVANCED_TIMESYNCHRONIZATION.oneofs_by_name['kind']
_ADVANCED_TIMESYNCHRONIZATION.oneofs_by_name['kind'].fields.append(
  _ADVANCED_TIMESYNCHRONIZATION.fields_by_name['ptp'])
_ADVANCED_TIMESYNCHRONIZATION.fields_by_name['ptp'].containing_oneof = _ADVANCED_TIMESYNCHRONIZATION.oneofs_by_name['kind']
_ADVANCED.fields_by_name['detector'].message_type = _ADVANCED_DETECTOR
_ADVANCED.fields_by_name['processing'].message_type = _ADVANCED_PROCESSING
_ADVANCED.fields_by_name['server'].message_type = _ADVANCED_SERVER
_ADVANCED.fields_by_name['time_synchronization'].message_type = _ADVANCED_TIMESYNCHRONIZATION
DESCRIPTOR.message_types_by_name['Advanced'] = _ADVANCED
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Advanced = _reflection.GeneratedProtocolMessageType('Advanced', (_message.Message,), {

  'Detector' : _reflection.GeneratedProtocolMessageType('Detector', (_message.Message,), {
    'DESCRIPTOR' : _ADVANCED_DETECTOR,
    '__module__' : 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.Detector)
    })
  ,

  'Processing' : _reflection.GeneratedProtocolMessageType('Processing', (_message.Message,), {
    'DESCRIPTOR' : _ADVANCED_PROCESSING,
    '__module__' : 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.Processing)
    })
  ,

  'Server' : _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
    'DESCRIPTOR' : _ADVANCED_SERVER,
    '__module__' : 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.Server)
    })
  ,

  'TimeSynchronization' : _reflection.GeneratedProtocolMessageType('TimeSynchronization', (_message.Message,), {

    'NTP' : _reflection.GeneratedProtocolMessageType('NTP', (_message.Message,), {
      'DESCRIPTOR' : _ADVANCED_TIMESYNCHRONIZATION_NTP,
      '__module__' : 'blickfeld.config.advanced_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.TimeSynchronization.NTP)
      })
    ,

    'PTP' : _reflection.GeneratedProtocolMessageType('PTP', (_message.Message,), {
      'DESCRIPTOR' : _ADVANCED_TIMESYNCHRONIZATION_PTP,
      '__module__' : 'blickfeld.config.advanced_pb2'
      # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.TimeSynchronization.PTP)
      })
    ,
    'DESCRIPTOR' : _ADVANCED_TIMESYNCHRONIZATION,
    '__module__' : 'blickfeld.config.advanced_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced.TimeSynchronization)
    })
  ,
  'DESCRIPTOR' : _ADVANCED,
  '__module__' : 'blickfeld.config.advanced_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.protocol.config.Advanced)
  })
_sym_db.RegisterMessage(Advanced)
_sym_db.RegisterMessage(Advanced.Detector)
_sym_db.RegisterMessage(Advanced.Processing)
_sym_db.RegisterMessage(Advanced.Server)
_sym_db.RegisterMessage(Advanced.TimeSynchronization)
_sym_db.RegisterMessage(Advanced.TimeSynchronization.NTP)
_sym_db.RegisterMessage(Advanced.TimeSynchronization.PTP)


_ADVANCED_DETECTOR.fields_by_name['sensitivity']._options = None
_ADVANCED_PROCESSING.fields_by_name['range_offset']._options = None
_ADVANCED_PROCESSING.fields_by_name['imu_static_rotation_offset']._options = None
_ADVANCED_PROCESSING.fields_by_name['horizontal_phase_offset']._options = None
_ADVANCED_TIMESYNCHRONIZATION_NTP.fields_by_name['servers']._options = None
_ADVANCED_TIMESYNCHRONIZATION_PTP.fields_by_name['unicast_destinations']._options = None
_ADVANCED_TIMESYNCHRONIZATION.oneofs_by_name['kind']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bf_proto/percept/data/state.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='bf_proto/percept/data/state.proto',
  package='blickfeld.percept.data',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!bf_proto/percept/data/state.proto\x12\x16\x62lickfeld.percept.data\x1a\x1fgoogle/protobuf/timestamp.proto\"\x88\x07\n\x05State\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13zone_algorithm_uuid\x18\x02 \x01(\t\x12\x38\n\x07\x63ounter\x18\x03 \x01(\x0b\x32%.blickfeld.percept.data.State.CounterH\x00\x12O\n\x13\x61\x63\x63umulated_counter\x18\x04 \x01(\x0b\x32\x30.blickfeld.percept.data.State.AccumulatedCounterH\x00\x12:\n\x08security\x18\x05 \x01(\x0b\x32&.blickfeld.percept.data.State.SecurityH\x00\x12<\n\toccupancy\x18\x06 \x01(\x0b\x32\'.blickfeld.percept.data.State.OccupancyH\x00\x12\x36\n\x06volume\x18\x07 \x01(\x0b\x32$.blickfeld.percept.data.State.VolumeH\x00\x1a\x97\x01\n\x07\x43ounter\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x38\n\x04type\x18\x02 \x01(\x0e\x32*.blickfeld.percept.data.State.Counter.Type\x12\x14\n\x0cobject_uuids\x18\x03 \x03(\t\"-\n\x04Type\x12\x0b\n\x07INBOUND\x10\x00\x12\x0c\n\x08OUTBOUND\x10\x01\x12\n\n\x06INSIDE\x10\x02\x1a\xbf\x01\n\x12\x41\x63\x63umulatedCounter\x12\r\n\x05\x63ount\x18\x01 \x01(\r\x12\x43\n\x04type\x18\x02 \x01(\x0e\x32\x35.blickfeld.percept.data.State.AccumulatedCounter.Type\x12\x32\n\x0estart_of_count\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"!\n\x04Type\x12\x0b\n\x07INBOUND\x10\x00\x12\x0c\n\x08OUTBOUND\x10\x01\x1a\x36\n\x08Security\x12\r\n\x05\x61larm\x18\x01 \x01(\x08\x12\x1b\n\x13num_detected_points\x18\x02 \x01(\r\x1a:\n\tOccupancy\x12\x10\n\x08occupied\x18\x01 \x01(\x08\x12\x1b\n\x13num_detected_points\x18\x02 \x01(\r\x1a\x18\n\x06Volume\x12\x0e\n\x06volume\x18\x01 \x01(\x02\x42\x0c\n\nstate_typeb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_STATE_COUNTER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='blickfeld.percept.data.State.Counter.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INBOUND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTBOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INSIDE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=604,
  serialized_end=649,
)
_sym_db.RegisterEnumDescriptor(_STATE_COUNTER_TYPE)

_STATE_ACCUMULATEDCOUNTER_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='blickfeld.percept.data.State.AccumulatedCounter.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INBOUND', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUTBOUND', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=604,
  serialized_end=637,
)
_sym_db.RegisterEnumDescriptor(_STATE_ACCUMULATEDCOUNTER_TYPE)


_STATE_COUNTER = _descriptor.Descriptor(
  name='Counter',
  full_name='blickfeld.percept.data.State.Counter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='blickfeld.percept.data.State.Counter.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blickfeld.percept.data.State.Counter.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object_uuids', full_name='blickfeld.percept.data.State.Counter.object_uuids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATE_COUNTER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=498,
  serialized_end=649,
)

_STATE_ACCUMULATEDCOUNTER = _descriptor.Descriptor(
  name='AccumulatedCounter',
  full_name='blickfeld.percept.data.State.AccumulatedCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='blickfeld.percept.data.State.AccumulatedCounter.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='blickfeld.percept.data.State.AccumulatedCounter.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='start_of_count', full_name='blickfeld.percept.data.State.AccumulatedCounter.start_of_count', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STATE_ACCUMULATEDCOUNTER_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=843,
)

_STATE_SECURITY = _descriptor.Descriptor(
  name='Security',
  full_name='blickfeld.percept.data.State.Security',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alarm', full_name='blickfeld.percept.data.State.Security.alarm', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_detected_points', full_name='blickfeld.percept.data.State.Security.num_detected_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=845,
  serialized_end=899,
)

_STATE_OCCUPANCY = _descriptor.Descriptor(
  name='Occupancy',
  full_name='blickfeld.percept.data.State.Occupancy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='occupied', full_name='blickfeld.percept.data.State.Occupancy.occupied', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_detected_points', full_name='blickfeld.percept.data.State.Occupancy.num_detected_points', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=901,
  serialized_end=959,
)

_STATE_VOLUME = _descriptor.Descriptor(
  name='Volume',
  full_name='blickfeld.percept.data.State.Volume',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='volume', full_name='blickfeld.percept.data.State.Volume.volume', index=0,
      number=1, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=985,
)

_STATE = _descriptor.Descriptor(
  name='State',
  full_name='blickfeld.percept.data.State',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='blickfeld.percept.data.State.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='zone_algorithm_uuid', full_name='blickfeld.percept.data.State.zone_algorithm_uuid', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counter', full_name='blickfeld.percept.data.State.counter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='accumulated_counter', full_name='blickfeld.percept.data.State.accumulated_counter', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='security', full_name='blickfeld.percept.data.State.security', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='occupancy', full_name='blickfeld.percept.data.State.occupancy', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='volume', full_name='blickfeld.percept.data.State.volume', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_STATE_COUNTER, _STATE_ACCUMULATEDCOUNTER, _STATE_SECURITY, _STATE_OCCUPANCY, _STATE_VOLUME, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='state_type', full_name='blickfeld.percept.data.State.state_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=95,
  serialized_end=999,
)

_STATE_COUNTER.fields_by_name['type'].enum_type = _STATE_COUNTER_TYPE
_STATE_COUNTER.containing_type = _STATE
_STATE_COUNTER_TYPE.containing_type = _STATE_COUNTER
_STATE_ACCUMULATEDCOUNTER.fields_by_name['type'].enum_type = _STATE_ACCUMULATEDCOUNTER_TYPE
_STATE_ACCUMULATEDCOUNTER.fields_by_name['start_of_count'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATE_ACCUMULATEDCOUNTER.containing_type = _STATE
_STATE_ACCUMULATEDCOUNTER_TYPE.containing_type = _STATE_ACCUMULATEDCOUNTER
_STATE_SECURITY.containing_type = _STATE
_STATE_OCCUPANCY.containing_type = _STATE
_STATE_VOLUME.containing_type = _STATE
_STATE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATE.fields_by_name['counter'].message_type = _STATE_COUNTER
_STATE.fields_by_name['accumulated_counter'].message_type = _STATE_ACCUMULATEDCOUNTER
_STATE.fields_by_name['security'].message_type = _STATE_SECURITY
_STATE.fields_by_name['occupancy'].message_type = _STATE_OCCUPANCY
_STATE.fields_by_name['volume'].message_type = _STATE_VOLUME
_STATE.oneofs_by_name['state_type'].fields.append(
  _STATE.fields_by_name['counter'])
_STATE.fields_by_name['counter'].containing_oneof = _STATE.oneofs_by_name['state_type']
_STATE.oneofs_by_name['state_type'].fields.append(
  _STATE.fields_by_name['accumulated_counter'])
_STATE.fields_by_name['accumulated_counter'].containing_oneof = _STATE.oneofs_by_name['state_type']
_STATE.oneofs_by_name['state_type'].fields.append(
  _STATE.fields_by_name['security'])
_STATE.fields_by_name['security'].containing_oneof = _STATE.oneofs_by_name['state_type']
_STATE.oneofs_by_name['state_type'].fields.append(
  _STATE.fields_by_name['occupancy'])
_STATE.fields_by_name['occupancy'].containing_oneof = _STATE.oneofs_by_name['state_type']
_STATE.oneofs_by_name['state_type'].fields.append(
  _STATE.fields_by_name['volume'])
_STATE.fields_by_name['volume'].containing_oneof = _STATE.oneofs_by_name['state_type']
DESCRIPTOR.message_types_by_name['State'] = _STATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

State = _reflection.GeneratedProtocolMessageType('State', (_message.Message,), {

  'Counter' : _reflection.GeneratedProtocolMessageType('Counter', (_message.Message,), {
    'DESCRIPTOR' : _STATE_COUNTER,
    '__module__' : 'bf_proto.percept.data.state_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.State.Counter)
    })
  ,

  'AccumulatedCounter' : _reflection.GeneratedProtocolMessageType('AccumulatedCounter', (_message.Message,), {
    'DESCRIPTOR' : _STATE_ACCUMULATEDCOUNTER,
    '__module__' : 'bf_proto.percept.data.state_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.State.AccumulatedCounter)
    })
  ,

  'Security' : _reflection.GeneratedProtocolMessageType('Security', (_message.Message,), {
    'DESCRIPTOR' : _STATE_SECURITY,
    '__module__' : 'bf_proto.percept.data.state_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.State.Security)
    })
  ,

  'Occupancy' : _reflection.GeneratedProtocolMessageType('Occupancy', (_message.Message,), {
    'DESCRIPTOR' : _STATE_OCCUPANCY,
    '__module__' : 'bf_proto.percept.data.state_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.State.Occupancy)
    })
  ,

  'Volume' : _reflection.GeneratedProtocolMessageType('Volume', (_message.Message,), {
    'DESCRIPTOR' : _STATE_VOLUME,
    '__module__' : 'bf_proto.percept.data.state_pb2'
    # @@protoc_insertion_point(class_scope:blickfeld.percept.data.State.Volume)
    })
  ,
  'DESCRIPTOR' : _STATE,
  '__module__' : 'bf_proto.percept.data.state_pb2'
  # @@protoc_insertion_point(class_scope:blickfeld.percept.data.State)
  })
_sym_db.RegisterMessage(State)
_sym_db.RegisterMessage(State.Counter)
_sym_db.RegisterMessage(State.AccumulatedCounter)
_sym_db.RegisterMessage(State.Security)
_sym_db.RegisterMessage(State.Occupancy)
_sym_db.RegisterMessage(State.Volume)


# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class Product(_Product, metaclass=_ProductEnumTypeWrapper):
    """*
    Product variant
    """
    pass
class _Product:
    V = typing.NewType('V', builtins.int)
class _ProductEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Product.V], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
    PRODUCT_CUBE = Product.V(0)
    PRODUCT_CUBE_RANGE = Product.V(2)

PRODUCT_CUBE = Product.V(0)
PRODUCT_CUBE_RANGE = Product.V(2)
global___Product = Product




"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class IMU(google.protobuf.message.Message):
    """*
    > Introduced in BSL v2.18 and firmware v1.19

    This section defines the status of the IMU.
    """
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class StaticState(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
        ACCELERATION_FIELD_NUMBER: builtins.int
        @property
        def acceleration(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
        def __init__(self,
            *,
            acceleration : typing.Optional[typing.Iterable[builtins.float]] = ...,
            ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal[u"acceleration",b"acceleration"]) -> None: ...

    STATIC_STATE_FIELD_NUMBER: builtins.int
    @property
    def static_state(self) -> global___IMU.StaticState: ...
    def __init__(self,
        *,
        static_state : typing.Optional[global___IMU.StaticState] = ...,
        ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal[u"static_state",b"static_state"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal[u"static_state",b"static_state"]) -> None: ...
global___IMU = IMU
